==> wiki3_4_0.zip: wiki3_4_0/plugin/access/Access.pm <==
package plugin::access::Access;
############################################################
# 
# ¿˥ڡ̾ɽޤ
# ɽǤޤ
# <pre>
# {{access 5}}
# </pre>
# Ĥɽ뤳ȤǤޤ
# <pre>
# {{access 5,v}}
# </pre>
# 
############################################################
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# 饤ؿ
#===========================================================
sub inline {
	my $self = shift;
	my $wiki = shift;
	my $max  = shift;
	my $way  = shift;
	
	if($way eq ""){
		$way = "H";
	}
	
	if($max eq "V" || $max eq "v"){
		$way = "V";
		$max = "";
	} elsif($max eq "H" || $max eq "h"){
		$way = "H";
		$max = "";
	}
	
	my ($line,%count);
	
	open(LOG,"$main::log_dir/$main::access_log_file") or return "";
	while(my $line=<LOG>){
		chomp $line;
		my ($page) = split(/ /,$line);
		$page = Util::url_decode($page);
		$count{$page}++;
	}
	close(LOG);
	
	my @keys;
	foreach(keys(%count)){
		push(@keys,$_);
	}
	@keys = sort {
		my $count1 = $count{$a};
		my $count2 = $count{$b};
		return $count2<=>$count1;
	} @keys;
	
	my $flag = 0;
	my $ret = "";
	
	if($way ne "H" && $way ne "h"){
		$ret .= "<ul>\n";
	}
	
	foreach(@keys){
		if($max ne "" && $flag==$max){
			last;
		}
		if($wiki->page_exists($_)){
			if($way eq "H" || $way eq "h"){
				if($flag!=0){ $ret = $ret." / "; }
			} else {
				$ret = $ret."<li>";
			}
			$ret = $ret."<a href=\"$main::script_name?page=".Util::url_encode($_)."\">".
			            Util::escapeHTML($_)."</a>(".$count{$_}.")";
			$flag++;
			
			if($way ne "H" && $way ne "h"){
				$ret .= "</li>\n";
			}
		}
	}
	
	if($way ne "H" && $way ne "h"){
		$ret .= "</ul>\n";
	}
	
	return $ret;
}

1;

==> wiki3_4_1.zip: wiki3_4_1/plugin/access/Access.pm <==
############################################################
# 
# ¿˥ڡ̾ɽޤ
# ɽǤޤ
# <pre>
# {{access 5}}
# </pre>
# Ĥɽ뤳ȤǤޤ
# <pre>
# {{access 5,v}}
# </pre>
# 
############################################################
package plugin::access::Access;
use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# 饤ؿ
#===========================================================
sub inline {
	my $self = shift;
	my $wiki = shift;
	my $max  = shift;
	my $way  = shift;
	
	if($way eq ""){
		$way = "H";
	}
	
	if($max eq "V" || $max eq "v"){
		$way = "V";
		$max = "";
	} elsif($max eq "H" || $max eq "h"){
		$way = "H";
		$max = "";
	}
	
	my ($line,%count);
	
	open(LOG,$wiki->config('log_dir')."/".$wiki->config('access_log_file')) or return "";
	while(my $line=<LOG>){
		chomp $line;
		my ($page) = split(/ /,$line);
		$page = Util::url_decode($page);
		$count{$page}++;
	}
	close(LOG);
	
	my @keys;
	foreach(keys(%count)){
		push(@keys,$_);
	}
	@keys = sort {
		my $count1 = $count{$a};
		my $count2 = $count{$b};
		return $count2<=>$count1;
	} @keys;
	
	my $flag = 0;
	my $ret = "";
	
	if($way ne "H" && $way ne "h"){
		$ret .= "<ul>\n";
	}
	
	foreach(@keys){
		if($max ne "" && $flag==$max){
			last;
		}
		if($wiki->page_exists($_)){
			if($way eq "H" || $way eq "h"){
				if($flag!=0){ $ret = $ret." / "; }
			} else {
				$ret = $ret."<li>";
			}
			$ret = $ret."<a href=\"".$wiki->config('script_name')."?page=".&Util::url_encode($_)."\">".
			            Util::escapeHTML($_)."</a>(".$count{$_}.")";
			$flag++;
			
			if($way ne "H" && $way ne "h"){
				$ret .= "</li>\n";
			}
		}
	}
	
	if($way ne "H" && $way ne "h"){
		$ret .= "</ul>\n";
	}
	
	return $ret;
}

1;
